<?php

/**
 * @file
 * Administrative page callbacks for the simple testimonials module.
 */

/**
 * Generates the settings form for the simple testimonials module.
 *
 * @param string $op
 *   Default value is NULL; determines what are the permissions of the current
 *   user on the testimonials.
 *
 * @return string
 *   The output, which contains the HTML code for the settings form generated by
 *   drupal_get_form() function.
 */
function simple_testimonials_settings_page($op = NULL) {
  $output = drupal_get_form('simple_testimonials_general_settings_form');

  return $output;
}

/**
 * Define a form to edit the page header and descriptive text.
 *
 * @return array
 *   The general settings form code stored in the $form variable, before
 *   converted to HTML.
 */
function simple_testimonials_general_settings_form($form) {

  $form['simple_testimonials_title'] = array(
    '#type' => 'textfield',
    '#title' => t('Title'),
    '#default_value' => variable_get('simple_testimonials_title', 'Testimonials'),
    '#description' => t('Testimonials, Recommendations, What People Are Saying, etc...'),
  );

  $form['body_filter']['simple_testimonials_description'] = array(
    '#type' => 'textarea',
    '#title' => t('Testimonials Description'),
    '#default_value' => variable_get('simple_testimonials_description', 'See what customers are saying about us.'),
    '#description' => t('Text that will be placed at the top of the page, above the testimonials and can serve as an introductory text.'),
    '#rows' => 5,
   // '#format' => variable_get('simple_testimonials_description_format', NULL),
  );

  $form['simple_testimonials_path_old'] = array(
    '#type' => 'hidden',
    '#value' => variable_get('simple_testimonials_path', 'testimonials'),
  );

  $form['simple_testimonials_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Testimonials Path'),
    '#description' => t('This option sets the path to the testimonials page. DO NOT append with a \'/\''),
    '#default_value' => variable_get('simple_testimonials_path', 'testimonials'),
  );

  $form = system_settings_form($form);
  $form['#submit'][] = 'simple_testimonials_general_settings_form_submit';
  return $form;
}

/**
 * Validate for general settings form.
 */
function simple_testimonials_general_settings_form_validate($form, &$form_state) {
  $path = $form_state['values']['simple_testimonials_path'];

  // Check if there is no special characters and trailing slash.
  $pattern = "/[\w-\/]+(?<!\/)$/";
  if (!preg_match($pattern, $path)) {
    form_set_error('simple_testimonials_path', t('Testimonials path is not correct.'));
  }
}

/**
 * Rebuilds the menu to account for adjustments to the testimonials_path variable.
 */
function simple_testimonials_general_settings_form_submit($form, &$form_state) {

  $oldpath = variable_get('simple_testimonials_path_old', 'testimonials');
  $newpath = variable_get('simple_testimonials_path', 'testimonials');

  $redirect = new stdClass();
  redirect_object_prepare(
    $redirect,
    array(
      'source' => $oldpath,
      'source_options' => array(),
      'redirect' => $newpath,
      'redirect_options' => array(),
      'language' => LANGUAGE_NONE,
    )
  );
  redirect_save($redirect);
  variable_set('simple_testimonials_path_old', $newpath);
  menu_rebuild();
}


